# Interactive map for engaged learning

**Course introduction: Where are you from?**

RShiny application where students can click a point on a map, and then submit this location, the observed value on that location and eventual a textstring with name, municipality etc. On a central projection, all submitted locations are shown as dots and summary statistics (such as: number of locations with a certain property) are shown.

---

**Student handheld view**

![](readme_illustration_student_view.jpg "")


---

**Lectureroom projection view**

![](readme_illustration_lectureroom_view.jpg "")

---

This script was initially developped in the summer of 2023, for courses related to physical geography regions at Wageningen University, by Ingrid Lubbers (concept, content, and testing with students; [ORCID: 0000-0002-2168-104X](https://orcid.org/0000-0002-2168-104X)) and Luc Steinbuch (coding; [ORCID: 0000-0001-6484-0920](https://orcid.org/0000-0001-6484-0920)). Last update in 2025. A frozen version can be found at [4TU data](https://doi.org/10.4121/5c515403-9762-47b9-b75f-ddfa15583444); a maintained version at https://git.wur.nl/stein012/course-introduction-map. Feel free to fork and improve your own copy, within the limitations of the license.

# License, citation, data source
The code is licensed under GNU General Public License v3.0. If possible, please cite the code similar to: "Interactive map for engaged learning: Source code in R Shiny. 2025. Luc Steinbuch and Ingrid Lubbers. 4TU data repository, doi [10.4121/5c515403-9762-47b9-b75f-ddfa15583444](https://doi.org/10.4121/5c515403-9762-47b9-b75f-ddfa15583444)". We would love to see this citation in the README with the derivatives of the code, in instruction manuals etc; please don't feel any obligation to show this citation in the webinterface, so while using this tool or any derivative during lectures.

The currently used map data about soil-landscape type ("Fysisch geografische regio") was downloaded from 
https://www.nationaalgeoregister.nl/geonetwork/srv/dut/catalog.search#/metadata/785fda82-16a1-4e71-b313-8212d404eddc, available under Public Domain Mark 1.0 (https://creativecommons.org/publicdomain/mark/1.0/deed.en), published by PDOK, The Netherlands. This data was processed: fewer fine details ("smoothed") for a smaller file size, and renamed for recognisability.

# Use for education

## Preparation

1. Set, in one of the first lines in `app.R`, the language (by un-commenting one of the two options: currently Dutch or English) 

2. Change, in one of the first lines in `app.R`, the deletion verification code and make sure to remember it
and an unique 

3. Eventual, change the text the students will see in `app.R` (see the definition of the `df_texts` dataframe).

4. Upload the scripts `app.R` and `server-definition.R` and to folders "data" folder and "student_data" to an R Shiny server (or find somebody who can do that for you ;-) )


Assuming the code, the "data" folder and the "student_data" folder have been correctly uploaded to an Rshiny server, it will provide you with an URL pointing you to the webpage: the user interface (UI). 

## Student use
Direct the students to the URL; they can follow the self-explanatory instructions on the screen. The screen size is adjusted for an handheld device, but also works on laptops. It can be helpful to show a QR code on the projection screen; if you are working at a Dutch educational institution, we recommend the SURF website [edu.nl](https://edu.nl/) to create a free, long-lasting, changeable and privacy-friendly QR code along with a shortcut URL.

## Teacher: projection use
Use the provided URL with `/?teacher`. This interactive map + histogram overview is optimized for a computer screen or a projection.

## Teacher: remove student data
After the lecture, or after the course, the student data should be removed (also for privacy reasons). You can use the provided URL with `/?remove`. You need to provide the earlier set deletion verification code. You might have to reload `/?teacher` (F5 in webbrowser) to spot the difference. Also mor ein general: when there are problems with displaying, reloading will probably solve those.

# Files and code
For an introduction to Rshiny, see https://shiny.posit.co/r/getstarted/shiny-basics/lesson1/.
The files `app.R` and `server-definition.R` contain the actual RShiny code, and take their input from `./data/FGR_dutch.RDS` with corresponding vector of colors `./data/color_scheme_dutch.RDS` (and similar in English). `main.R` shows how the raw data (stored in `./data_downl/v1_0.json`) is processed into the mentioned data working files. During a session, the location etc from each participant is stored in `.csv` format in `./student_data`; the file `./student_data/placeholder_to_copy_this_directory` smoothens the publishing/uploading process.

Th current code is optimised for the given variable with seven catagories. Adjusting it for other variables (such as elevation, risk of flooding etc.) will require adjustments on several places, both in the code as well as the delivered dataset. For code readability, we used the RStudio header indication (`#### ...... ####`) and prefix many object names with an indication of the class of the object: `df_` means "dataframe", `vs_` means "vector of strings" etc.

# Test results

First tested on Thursday 2nd of November, 2023:

- Almost every student used a mobile device; for that use, it was unclear that one has to scroll down (improved)

- Within ca. 5 minutes, about 120 students provided their location. We used the RShiny server settings *Max processes = 20*, *Max connections per process = 30*, *Load factor = 0.8*; we didn't experience any performance problems. In later performances, we didn't adjust the default settings of our RShiny server anymore.

- The greay area with "Locations and basic soil-landscape types from: ... " remained one line, rather than breaking. (solved)

- It worked quite well, apart from the fact that many students have their origin outside The Netherlands resulting in many "no data" observations.

In the updated version, the height of the map and plot is set higher for the teacher version and smaller for the student version. The title on top has a smaller font.


# Perceived advantages

- One can do this exercise with a large group of students within 5 minutes

- With a given set-up, the tool can be re-used over several courses with a similar topic

- The students' attention is immediately attracted because the teaching material is related to their own origin or life situation

- The student  learn what physical geographical regions there are in Nl; sample of how many people live where also usually matches demography; the content of the course goes on to explain why many people live somewhere, and why that is a good/bad idea
