#### Set language ####
#str_language <<- "Dutch"
str_language <<- "English"

#### Set deletion verification code ####
## no leading or trailing spaces, no special characters, just one line, string
str_deletion_verification_code <<- "3635"


#### Set up initial point ####
## In this case the WUR campus. Having an initial location point prevents
## us to take into account that there might be no input at all.

if(str_language == "Dutch")
  str_voi_initial <- "Zandlandschap"
if(str_language == "English")
  str_voi_initial <- "Sand landscape"
## When done incorrectly, this will give error messages like "Error: [object Object]" and
##  "Problem while setting up geom aesthetics"

df_initial_loc_and_var <<-
  structure(list(lon = 5.6631946563720703, lat = 51.982977121673997,
                 variable_of_interest = str_voi_initial, student_name = "WUR campus, Wageningen",
                 time_of_submitting = Sys.time()), row.names = c(NA, -1L), class = "data.frame")


#### Define all displayed texts in the two languages ####
df_texts <<- data.frame(
  row.names = c("title_of_page",
                "source",
                "course",
                "intro_source_data",
                "disclaimer",
                "layer_name",
                "first_instructions_zoom_and_click",
                "invite_to_submit_location",
                "degrees_north_latitude",
                "degrees_east_longitude",
                "ask_for_name",
                "submit_location",
                "thanks_for_submitting",
                "n_of_locations",
                "locations_from"
  ),
  English = c("Soil and landscape: where do you come from?",          # title_of_page
              "Application created by WUR/SGL, 2025 for the course", # source
              "Introduction to Soil Geography (SGL-12803)",           # course
              "Shown data are from the Dutch ",                       # intro_source_data
              "but processed and only meant to be used within this educational context.
               The  personal datum 'location', and the optional personal data such as 'name', 'municipality' etc. are stored on the WUR RShiny server.
               All these data will only be used for this exercise and will be deleted soon afterwards. It is not obligatory to submit any of this data.
               Ask the SGL data steward for more info regaring privacy.",  # disclaimer
              "Basic soil-landscape type",                            # layer_name
              "Please zoom in to your origin, and click/tap",         # first_instructions_zoom_and_click
              "Please submit your location!",                         # invite_to_submit_location
              "degrees latitude North",                               # degrees_north_latitude
              "degrees longitude East",                               # degrees_east_longitude
              "If you want: your name, municipality etc.",            # ask_for_name
              "Submit your latest location",                          # submit_location
              "Your location has been submitted!",                    # thanks_for_submitting
              "# locations",                                          # n_of_locations
              "Locations and basic soil-landscape types from: "       # locations_from
  ),
  Dutch   = c("Fysisch Geografische Regio's: waar kom jij vandaan?",       # title_of_page
              "Gemaakt door WUR/SGL, 2025 voor het vak",                  # source
              "Introduction to Geology, Soils and Landscapes (SGL-13806)", # course
              "De gebruikte gegevens komen van het",                      # intro_source_data
              "maar zijn bewerkt en als zodanig alleen bedoeld voor deze oefening.
               De persoonlijke gegevens zoals 'locatie', 'gemeente' en dergelijke  worden opgeslagen op de WUR RShiny server.
               All deze gegevens worden alleen voor deze oefening gebruikt en worden daarna verwijderd.
               Je bent niet verplicht deze gegevens in te voeren.
               Vraag de SGL data steward voor meer informatie mbt. privacy.",   # disclaimer
              "Fysisch geografische regio",                                # layer_name
              "Kun je aangeven waar je vandaan komt?",                     # first_instructions_zoom_and_click
              "Nu kun je je locatie doorgeven!",                           # invite_to_submit_location
              "graden Noorderbreedte",                                     # degrees_north_latitude
              "graden Oosterlengte",                                       # degrees_east_longitude
              "Als je wilt: jouw naam, woonplaats oid.",                   # ask_for_name
              "Verstuur jouw laatste locatie",                             # submit_location
              "Jouw locatie is doorgegeven!",                              # thanks_for_submitting
              "# locaties",                                                # n_of_locations
              "Locaties en basis bodemtypes van: "                         # locations_from
  )

)


#### Standard settings, libraries etc. ####

library(ggplot2)
library(htmlwidgets)
library(leaflet)
library(mapview)
library(sf)
library(shiny)
library(shinyBS)
library(tidyverse)
library(viridis)

source("server-definition.R")

options(bitmapType='cairo')
# To avoid "Unable to open connecting to X11 display"

if(str_language == "English")
{
  ## Read data Dutch Fysisch Geografische Regio's into global variables
  sf_mapVOI <<- readRDS(file="./data/FGR_eng.RDS")
  vs_colors <<- readRDS(file="./data/color_scheme_eng.RDS")

  ## Which value get points outside the provided map?
  str_Outside_Map <<- "No soils/urban soils/no data"
}
if(str_language == "Dutch")
{
  sf_mapVOI <<- readRDS(file="./data/FGR_dutch.RDS")
  vs_colors <<- readRDS(file="./data/color_scheme_dutch.RDS")

  ## Which value get points outside the provided map?
  str_Outside_Map <<- "Geen bodem / stadsbodem / geen data"
}



#### Outline user interface; start up webserver ####
## Note that the majority of the user interface is defined in the server function definition

## Outline of user interface
ui <- fluidPage(
  p(df_texts["title_of_page", str_language]),
  uiOutput('myUI'),
  hr(),
  # p("Application created by WUR/SGL, 2023 for the course ", em(""), ".
  #   Shown data are from the Dutch ",
  #   a("Nationaal Georegister",
  #     href="https://www.nationaalgeoregister.nl/geonetwork/srv/dut/catalog.search#/metadata/785fda82-16a1-4e71-b313-8212d404eddc",
  #     target="_blank"
  #     ),
  #   "but processed and only meant to be used within this educational context.
  #   The  personal datum 'location', and the optional personal data such as 'name', 'municipality' etc. are stored on the WUR RShiny server.
  #   All these data will only be used for this exercise and will be deleted soon afterwards. It is not obligatory to submit any of this data. For more information, please contact one of the lecturers.",
  #   style = "font-size:60%;"
  #   )
  p(df_texts["source", str_language], " ", em(df_texts["course", str_language]), ". ",
    df_texts["intro_source_data", str_language], " ",
    a("Nationaal Georegister",
      href="https://www.nationaalgeoregister.nl/geonetwork/srv/dut/catalog.search#/metadata/785fda82-16a1-4e71-b313-8212d404eddc",
      target="_blank"
    ),
    df_texts["disclaimer", str_language],
    style = "font-size:60%;"
  )

)


shinyApp(ui = ui, server = server)


