library(dplyr)
#install.packages("rmapshaper")
library(rmapshaper)

#### Prepare data ####

## Download json from https://www.nationaalgeoregister.nl/geonetwork/srv/dut/catalog.search#/metadata/785fda82-16a1-4e71-b313-8212d404eddc

## Load into R
sf_map <-  sf::read_sf( "./data_downl/v1_0.json")

## Transform to best known coordinate reference system
sf_map <- sf::st_transform(sf_map, "WGS84")

## make file smaller with smooting
sf_map <- rmapshaper::ms_simplify(sf_map, keep=0.1)

plot(sf_map["fgr"])


## Rename category names
df_translate <- data.frame(
  original   = c("Duinen",
                 "Getijdengebied",
                 "Heuvelland",
                 "Hogere Zandgronden",
                 "Laagveengebied",
                 "Niet indeelbaar",
                 "Rivierengebied",
                 "Zeekleigebied",
                 "Afgesloten Zeearmen",
                 "Noordzee"
  ),
  english = c("Dune and coastal sand landscape",
              "No soils/urban soils/no data",
              "Loess landscape",
              "Sand landscape",
              "Peat landscape",
              "No soils/urban soils/no data",
              "River clay landscape",
              "Marine clay landscape",
              "No soils/urban soils/no data",
              "No soils/urban soils/no data"
              ),
  dutch = c("Kustlandschap",
              "Geen bodem / stadsbodem / geen data",
              "Löss landschap",
              "Zandlandschap",
              "Veenlandschap",
              "Geen bodem / stadsbodem / geen data",
              "Rivierkleilandschap",
              "Zeekleilandschap",
              "Geen bodem / stadsbodem / geen data",
              "Geen bodem / stadsbodem / geen data"
  )

)


sf_map_dutch <- sf_map

for (i in (1:nrow(df_translate)))
{
  sf_map_dutch <- sf_map_dutch %>%
      mutate(fgr = replace(x = fgr,
                           list = (fgr == df_translate$original[i]),
                           values = df_translate$dutch[i])
      )
}

names(sf_map_dutch)

names(sf_map_dutch)[4] <- "voi"  # More general: Variable of interest

saveRDS(sf_map_dutch,file="./data/FGR_dutch.RDS")

#### Create map with English names ####

for (i in (1:nrow(df_translate)))
{
  sf_map <- sf_map %>%
    mutate(fgr = replace(x = fgr,
                         list = (fgr == df_translate$original[i]),
                         values = df_translate$english[i])
    )
}

names(sf_map)

names(sf_map)[4] <- "voi"  # More general: Variable of interest

plot(sf_map["voi"])

saveRDS(sf_map,file="./data/FGR_eng.RDS")


### Define corresponding colorscheme for the 7 categories
## The order happens to be different per language, because of
## alphabetic ordering by GGPLOT etc.

## Dutch
df_colors <- data.frame(voi = sort(unique(sf_map_dutch$voi)),
                        map_color = NA)

## Dune
df_colors$map_color[2] <- rgb(red = 239, green = 240, blue = 186, maxColorValue = 255)
## Loess
df_colors$map_color[3] <- rgb(red = 238, green = 211, blue = 210, maxColorValue = 255)
## Marine clay
df_colors$map_color[7] <- rgb(red = 216, green = 230, blue = 233, maxColorValue = 255)
## No...
df_colors$map_color[1] <- rgb(red = 213, green = 218, blue = 220, maxColorValue = 255)
## Peat
df_colors$map_color[5] <- rgb(red = 242, green = 216, blue = 235, maxColorValue = 255)
## River clay
df_colors$map_color[4] <- rgb(red = 227, green = 233, blue = 215, maxColorValue = 255)
## Sand
df_colors$map_color[6] <- rgb(red = 242, green = 233, blue = 212, maxColorValue = 255)

saveRDS(df_colors$map_color,file="./data/color_scheme_dutch.RDS")


## English
df_colors <- data.frame(voi = sort(unique(sf_map$voi)))
## Dune
df_colors$map_color[1] <- rgb(red = 239, green = 240, blue = 186, maxColorValue = 255)
## Loess
df_colors$map_color[2] <- rgb(red = 238, green = 211, blue = 210, maxColorValue = 255)
## Marine clay
df_colors$map_color[3] <- rgb(red = 216, green = 230, blue = 233, maxColorValue = 255)
## No...
df_colors$map_color[4] <- rgb(red = 213, green = 218, blue = 220, maxColorValue = 255)
## Peat
df_colors$map_color[5] <- rgb(red = 242, green = 216, blue = 235, maxColorValue = 255)
## River clay
df_colors$map_color[6] <- rgb(red = 227, green = 233, blue = 215, maxColorValue = 255)
## Sand
df_colors$map_color[7] <- rgb(red = 242, green = 233, blue = 212, maxColorValue = 255)

saveRDS(df_colors$map_color,file="./data/color_scheme_eng.RDS")


